@@ -131,8 +131,9 @@ void MainWindow::slotMenu(int id)
 			synchronize();
 			break;
 		case game_seats:
-			seats = new KGGZSeatsDialog();
-			seats->setMod(network->getMod());
+			/*seats = new KGGZSeatsDialog();
+			seats->setMod(network->getMod());*/
+			// FIXME: disabled until ported to kggzmod
 			break;
 #ifdef HAVE_KNEWSTUFF
 		case game_newlevels:
@@ -256,8 +257,8 @@ void MainWindow::scanLevels(QString basedir)
 
 void MainWindow::scanNewLevels()
 {
-	KStandardDirs d;
-	QString basedir = d.findResource("data", "fyrdman/");
+	KStandardDirs *d = KGlobal::dirs();
+	QString basedir = d->findResource("data", "fyrdman/");
 	QDir dir(basedir);
 	QStringList s = dir.entryList();
 	for(QStringList::iterator it = s.begin(); it != s.end(); it++)
