@@ -18,6 +18,8 @@ class Network : public QObject
 		int fd();
 		int cfd();
 
+		GGZMod *getMod();
+
 		enum ServerToClient
 		{
 			msgseat = 0,
@@ -59,7 +61,8 @@ class Network : public QObject
 		int m_fd, m_cfd;
 
 		static Network *me;
-		static void handle(GGZMod *mod, GGZModEvent e, void *data);
+		static void handle(GGZMod *mod, GGZModEvent e,
+				   const void *data);
 		static GGZMod *mod;
 };
 
