@@ -23,12 +23,14 @@ class KDots : public QWidget
 {
 	Q_OBJECT
 	public:
-		KDots(QWidget *parent = NULL, const char *name = NULL);
+		KDots(bool ggzmode, QWidget *parent = NULL, const char *name = NULL);
 		~KDots();
 		void gameinit();
 		void gamesync();
 		void input();
 
+		KDotsProto *getProto();
+
 	public slots:
 		void slotOptions();
 		void slotStart(int horizontal, int vertical);
