@@ -18,12 +18,13 @@
 class KDots;
 class KDotsAbout;
 class KDotsHelp;
+class KDotsReplay;
 
 class KDotsWin : public KMainWindow
 {
 	Q_OBJECT
 	public:
-		KDotsWin();
+		KDotsWin(bool ggzmode);
 		~KDotsWin();
 
 		enum MenuItems
@@ -31,7 +32,9 @@ class KDotsWin : public KMainWindow
 			menuhelp,
 			menuabout,
 			menuquit,
-			menusync
+			menusync,
+			menureplay,
+			menuseats
 		};
 	
 	public slots:
@@ -43,6 +46,7 @@ class KDotsWin : public KMainWindow
 		KDots *m_dots;
 		KDotsAbout *kdots_about;
 		KDotsHelp *kdots_help;
+		KDotsReplay *kdots_replay;
 		QWidget *m_color;
 };
 
