@@ -32,10 +32,7 @@
 #include <qcursor.h>
 #include <qfile.h>
 
-#ifdef HAVE_RSVG
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <librsvg/rsvg.h>
-#endif
+#include "qsvgpixmap.h"
 
 #include "board.h"
 #include "board.moc"
@@ -43,12 +40,12 @@
 ChessBoard::ChessBoard(QWidget *parent, const char *name)
 	: QWidget(parent, name, Qt::WNoAutoErase)
 {
-	KStandardDirs d;
+	KStandardDirs *d = KGlobal::dirs();
 
 	kdDebug(12101) << "ChessBoard::ChessBoard()" << endl;
 
 	// load figure pixmaps
-	QString pixmapdir = d.findResource("data", "koenig/pics/");
+	QString pixmapdir = d->findResource("data", "koenig/pics/");
 	setTheme(pixmapdir);
 
 	// I like QuickHacks ;)
@@ -107,48 +104,7 @@ void ChessBoard::setTheme(QString pixmapdir)
 
 QPixmap ChessBoard::svgPixmap(QString filename)
 {
-	QPixmap tmp;
-#ifdef HAVE_RSVG
-	GError *error = NULL;
-	const int width = 128;
-	const int height = 128;
-	bool bigendian = false;
-
-	g_type_init();
-	GdkPixbuf *buf = rsvg_pixbuf_from_file_at_size(filename.latin1(), width, height, &error);
-
-	if(buf)
-	{
-		guchar *foo = gdk_pixbuf_get_pixels(buf);
-		int test = 1;
-		if(!(*(char*)&test & 0xFF)) bigendian = true;
-		if(bigendian)
-		{
-			for(int i = 0; i < width; i++)
-				for(int j = 0; j < height; j++)
-				{
-					unsigned int pixel = *(unsigned int*)(foo + (j * width + i) * 4);
-					int a, r, g, b;
-					r = (pixel >> 24) & 0xFF;
-					g = (pixel >> 16) & 0xFF;
-					b = (pixel >> 8) & 0xFF;
-					a = (pixel >> 0) & 0xFF;
-					pixel = (a << 24) + (r << 16) + (g << 8) + (b << 0);
-					*(unsigned int*)(foo + (j * width + i) * 4) = pixel;
-				}
-		}
-
-		QImage im(gdk_pixbuf_get_pixels(buf), gdk_pixbuf_get_width(buf), gdk_pixbuf_get_height(buf),
-			gdk_pixbuf_get_bits_per_sample(buf) * 4, 0, 0, QImage::IgnoreEndian);
-		im.setAlphaBuffer(true);
-		tmp.convertFromImage(im);
-	}
-	else tmp = QPixmap(filename + ".png");
-#else
-	tmp = QPixmap(filename + ".png");
-#endif
-	if(tmp.isNull()) tmp = QPixmap(filename.replace("svg", "png"));
-	return tmp;
+	return QSvgPixmap::pixmap(filename, 128, 128);
 }
 
 void ChessBoard::resetBoard(int color)
