@@ -292,8 +292,8 @@ void TopLevel::slotNewstuff()
 	KNS::DownloadDialog::open("chess/theme");
 #endif
 
-	KStandardDirs d;
-	QString basedir = d.findResource("data", "koenig/");
+	KStandardDirs *d = KGlobal::dirs();
+	QString basedir = d->findResource("data", "koenig/");
 	QDir dir(basedir);
 	QStringList s = dir.entryList(QDir::Files);
 	for(QStringList::iterator it = s.begin(); it != s.end(); it++)
@@ -322,10 +322,11 @@ void TopLevel::slotNewstuff()
 
 void TopLevel::slotSeats()
 {
-	KGGZSeatsDialog *seats;
+	/*KGGZSeatsDialog *seats;
 
 	seats = new KGGZSeatsDialog();
-	seats->setMod(game->getGGZ()->getMod());
+	seats->setMod(game->getGGZ()->getMod());*/
+	// FIXME: disabled until port to kggzmod
 }
 
 bool TopLevel::queryClose()
